@@ -1,10 +1,11 @@
 package Pcore::Handle::pgsql;
 
-use Pcore -class, -const, -result, -sql,
+use Pcore -class, -const, -result,
   -export => {
     STATE     => [qw[$STATE_CONNECT $STATE_READY $STATE_BUSY $STATE_DISCONNECTED]],
     TX_STATUS => [qw[$TX_STATUS_IDLE $TX_STATUS_TRANS $TX_STATUS_ERROR]],
   };
+use Pcore::Handle::DBI::Const qw[:CONST];
 use Pcore::Util::Scalar qw[looks_like_number is_plain_arrayref];
 use Pcore::Util::UUID qw[uuid_str];
 
@@ -262,10 +263,10 @@ PERL
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
 ## |    3 |                      | Subroutines::ProhibitUnusedPrivateSubroutines                                                                  |
-## |      | 81                   | * Private subroutine/method '_get_dbh' declared but not used                                                   |
-## |      | 152                  | * Private subroutine/method '_get_schema_patch_table_query' declared but not used                              |
+## |      | 82                   | * Private subroutine/method '_get_dbh' declared but not used                                                   |
+## |      | 153                  | * Private subroutine/method '_get_schema_patch_table_query' declared but not used                              |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 215, 237             | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
+## |    3 | 216, 238             | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
