@@ -1,8 +1,9 @@
 package Pcore::PgSQL::DBH;
 
-use Pcore -class, -result, -const, -sql;
+use Pcore -class, -result, -const;
+use Pcore::Handle::DBI::Const qw[:CONST];
 use Pcore::Handle::pgsql qw[:ALL];
-use Pcore::Util::Scalar qw[weaken looks_like_number is_plain_arrayref is_plain_coderef];
+use Pcore::Util::Scalar qw[weaken looks_like_number is_plain_arrayref is_plain_coderef is_blessed_arrayref];
 use Pcore::Util::UUID qw[uuid_str];
 use Pcore::Util::Digest qw[md5_hex];
 use Pcore::AE::Handle;
@@ -604,7 +605,7 @@ sub _execute ( $self, $query, $bind, $cb, %args ) {
             my @bind = $bind->@*;
 
             for my $param (@bind) {
-                if ( is_plain_arrayref $param) {
+                if ( is_blessed_arrayref $param) {
                     if ( $param->[1] == $SQL_BYTEA ) {
                         $param_format_codes .= "\x00\x01";    # binary
 
@@ -981,20 +982,20 @@ sub quote ( $self, $var, $type = undef ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 179                  | ControlStructures::ProhibitCascadingIfElse - Cascading if-elsif chain                                          |
+## |    3 | 180                  | ControlStructures::ProhibitCascadingIfElse - Cascading if-elsif chain                                          |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 524                  | Subroutines::ProhibitExcessComplexity - Subroutine "_execute" with high complexity score (27)                  |
+## |    3 | 525                  | Subroutines::ProhibitExcessComplexity - Subroutine "_execute" with high complexity score (27)                  |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 898                  | ControlStructures::ProhibitDeepNests - Code structure is deeply nested                                         |
+## |    3 | 899                  | ControlStructures::ProhibitDeepNests - Code structure is deeply nested                                         |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 26, 149, 357, 515,   | ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       |
-## |      | 583, 593, 609, 614,  |                                                                                                                |
-## |      | 619, 625, 634, 641,  |                                                                                                                |
-## |      | 645, 649, 653, 656   |                                                                                                                |
+## |    2 | 27, 150, 358, 516,   | ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       |
+## |      | 584, 594, 610, 615,  |                                                                                                                |
+## |      | 620, 626, 635, 642,  |                                                                                                                |
+## |      | 646, 650, 654, 657   |                                                                                                                |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 735, 898             | ControlStructures::ProhibitCStyleForLoops - C-style "for" loop used                                            |
+## |    2 | 736, 899             | ControlStructures::ProhibitCStyleForLoops - C-style "for" loop used                                            |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 774                  | ControlStructures::ProhibitPostfixControls - Postfix control "for" used                                        |
+## |    2 | 775                  | ControlStructures::ProhibitPostfixControls - Postfix control "for" used                                        |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
